import axios from 'axios';
import { ListParams, queryList } from '@/api/list';

export interface RoleCreateRecord {
  id: number | undefined;
  name: string;
  dataScope: string;
  permissionIds: (number | undefined)[];
  remark: string;
}

// 基础信息
export interface RoleList {
  id: string;
  remark: string;
  name: string;
  enabled: string;
  authorities: string;
}

export interface RoleRecord extends RoleCreateRecord {
  permissions?: [];
}

export interface RoleListRecord extends RoleRecord {
  name: string;
}

// 查询所有的角色列表、
export function getRoleList() {
  return axios.get('/api/rest/role');
}

// 切换启用状态
export function enabled(id: string) {
  return axios.patch(`/api/rest/role/${id}/toggle`);
}

// 删除用户
export function remove(id: string) {
  return axios.delete(`/api/rest/role/${id}`);
}

// 添加角色
export function create(data: RoleList) {
  return axios.post(`/api/rest/role`, data);
}

// 更新用户
export function update(data: RoleList) {
  return axios.patch(`/api/rest/role/${data.id}`, data);
}

export function getDetail(id: number) {
  return axios.get<RoleRecord>(`/api/rest/role/${id}`);
}

export function queryRoles(params?: ListParams<Partial<RoleRecord>>) {
  return queryList<RoleRecord>(`/api/rest/role/query`, params);
}
